Model

Struct Model 

pub struct Model { /* private fields */ }

Implementations

Source

impl Model

pub fn load(path: &PathBuf) -> Result<Self>

pub fn load_with_mmap(path: &PathBuf) -> Result<(Mmap, Self)>

pub fn prefetch_mmap(_mmap: &Mmap)

No-op. madvise hints are now applied inside load_with_mmap() immediately after the mmap is created and before tensor data is read, which is the only point where they have effect. Calling this after load returns is useless.

pub fn metadata(&self) -> &GgufMetadata

pub fn clear_kv_cache(&mut self)

pub fn forward(&mut self, tokens: &[u32], pos: usize) -> Result<Tensor>