pub struct Model { /* private fields */ }Expand description
High-level model wrapper with builder pattern for text generation.
Use this when you need to:
- Generate multiple times with the same model
- Use streaming callbacks
- Maintain conversation history
- Access model metadata
Example
ⓘ
use oxide_rs::Model;
let mut model = Model::new("model.gguf")?
.with_options(oxide_rs::GenerateOptions {
max_tokens: 256,
temperature: 0.7,
..Default::default()
})
.load()?;
let response = model.generate("Hello!")?;
println!("{}", response);Implementations
Sourceimpl Model
impl Model
Sourcepub fn with_options(self, options: GenerateOptions) -> Self
pub fn with_options(self, options: GenerateOptions) -> Self
Sourcepub fn with_tokenizer<P: AsRef<Path>>(self, tokenizer_path: P) -> Self
pub fn with_tokenizer<P: AsRef<Path>>(self, tokenizer_path: P) -> Self
Sourcepub fn generate_stream<F>(
&mut self,
prompt: &str,
callback: F,
) -> Result<String, Box<dyn Error>>
pub fn generate_stream<F>( &mut self, prompt: &str, callback: F, ) -> Result<String, Box<dyn Error>>
Generate text with streaming callback.
Tokens are passed to the callback as they’re generated, enabling real-time output display.
Requires load() to be called first.
Arguments
prompt- The input promptcallback- Function called for each generated token
Example
ⓘ
model.generate_stream("Tell me a story", |token| {
print!("{}", token);
})?;Sourcepub fn generate_batch(
&mut self,
prompts: Vec<String>,
) -> Result<Vec<String>, Box<dyn Error>>
pub fn generate_batch( &mut self, prompts: Vec<String>, ) -> Result<Vec<String>, Box<dyn Error>>
Generate text from multiple prompts in batch.
Processes multiple prompts sequentially, sharing the loaded model for efficiency. Each prompt generates independently with its own output.
Requires load() to be called first.
Arguments
prompts- Vector of input prompts
Example
ⓘ
let prompts = vec!["Hello!", "How are you?", "What's up?"];
let results = model.generate_batch(prompts)?;
for result in results {
println!("{}", result);
}Sourcepub fn clear_history(&mut self)
pub fn clear_history(&mut self)
Sourcepub fn metadata(&self) -> Option<&GgufMetadata>
pub fn metadata(&self) -> Option<&GgufMetadata>
Sourcepub fn context_used(&self) -> Option<usize>
pub fn context_used(&self) -> Option<usize>
Sourcepub fn context_limit(&self) -> Option<usize>
pub fn context_limit(&self) -> Option<usize>